Binned
--------------------------------------------------------------------------------

Components that are needed to create binned data or PDFs.

.. autosummary::
    :toctree: _generated/data

    zfit.binned.RegularBinning
    zfit.binned.VariableBinning
